/*
 * @Author: 吴永生#A02208 yongsheng.wu@wholion.com
 * @Date: 2022-05-31 10:18:13
 * @LastEditors: 吴永生#A02208 yongsheng.wu@wholion.com
 * @LastEditTime: 2022-06-01 09:15:10
 * @FilePath: /bkunyun/src/views/Project/ProjectSetting/index.tsx
 * @Description: 这是默认设置,请设置`customMade`, 打开koroFileHeader查看配置 进行设置: https://github.com/OBKoro1/koro1FileHeader/wiki/%E9%85%8D%E7%BD%AE
 */
import { memo, useEffect, useMemo, useState } from "react";

import style from "./index.module.css";
import useMyRequest from "@/hooks/useMyRequest";
import {
  getProject,
  hpczone,
  updateProject,
  deleteProject,
} from "@/api/project_api";
import { useStores } from "@/store";
import { observer } from "mobx-react-lite";
import InformationDisplay from "@/components/InformationDisplay";
import classnames from "classnames";
import { Button } from "@mui/material";

type zoneIdOption = {
  id: string;
  name: string;
};

const BaseInfo = observer(() => {
  const { currentProjectStore } = useStores();
  const [projectInfo, setProjectInfo] = useState<any>({});
  const currentUserName = JSON.parse(
    localStorage.getItem("userInfo") || "{}"
  ).name;
  const { run } = useMyRequest(getProject, {
    onSuccess: (result: any) => {
      setProjectInfo(result.data);
    },
  });
  useEffect(() => {
    run({
      id: currentProjectStore.currentProjectInfo.id as string,
    });
  }, [currentProjectStore, run]);
  const [zoneIdMap, setZoneIdMap] = useState<Map<string, string>>(new Map());
  const [zoneIdOptions, setZoneIdOptions] = useState<Array<zoneIdOption>>([]);
  const { run: getZone } = useMyRequest(hpczone, {
    onSuccess: (result: any) => {
      setZoneIdOptions(result);
      let zoneMap: Map<string, string> = new Map();
      result.forEach((item: zoneIdOption) => {
        zoneMap.set(item.id, item.name);
      });
      setZoneIdMap(zoneMap);
    },
  });
  useEffect(() => {
    getZone();
  }, [getZone]);
  const infoList = useMemo(() => {
    return [
      {
        label: "项目名称：",
        value: projectInfo.name,
      },
      {
        label: "项目描述：",
        value: projectInfo.desc,
      },
      {
        label: "计算区：",
        value: zoneIdMap.get(projectInfo.zoneId) || projectInfo.zoneId,
      },
      {
        label: "创建人：",
        value: projectInfo.owner,
      },
      {
        label: "扣费账号：",
        value: projectInfo.tenantUser,
      },
    ];
  }, [projectInfo, zoneIdMap]);

  const nameChange = (e: any) => {
    setProjectInfo({
      ...projectInfo,
      name: e.target.value,
    });
  };

  const descChange = (e: any) => {
    setProjectInfo({
      ...projectInfo,
      desc: e.target.value,
    });
  };

  const { run: updateProjectRun } = useMyRequest(updateProject, {
    onSuccess: (result: any) => {
      console.log("修改成功");
    },
  });

  const handleClickUpdate = () => {
    if (projectInfo.name) {
      updateProjectRun({ ...projectInfo, product: "CADD" });
    } else {
      console.log("请输入项目名称");
      return;
    }
    console.log("handleClickUpdate");
  };

  const { run: deleteProjectRun } = useMyRequest(deleteProject, {
    onSuccess: (result: any) => {
      console.log("删除成功");
    },
  });

  const handleClickDelete = () => {
    console.log("handleClickDelete");
    deleteProjectRun({ id: projectInfo.id });
  };

  if (currentUserName === projectInfo.owner) {
    return (
      <div className={style.projectInfoList}>
        <div className={style.projectInfoListLi}>
          <div
            className={classnames({
              [style.projectInfoListLiLabel]: true,
              [style.projectInfoName]: true,
            })}
            placeholder="请输入项目名称"
          >
            项目名称
          </div>
          <input
            value={projectInfo.name}
            className={style.projectInfoListLiValue}
            onChange={nameChange}
            maxLength={30}
          ></input>
        </div>
        <div className={style.projectInfoListLi}>
          <div className={style.projectInfoListLiLabel}>项目描述</div>
          <textarea
            value={projectInfo.desc}
            className={classnames({
              [style.projectInfoListLiValue]: true,
              [style.projectInfoTextarea]: true,
            })}
            onChange={descChange}
            placeholder="项目描述限制100字以内"
            maxLength={100}
          ></textarea>
        </div>
        <div className={style.projectInfoListLi}>
          <div className={style.projectInfoListLiLabel}>计算区</div>
          <select
            value={projectInfo.zoneId}
            disabled
            className={classnames({
              [style.projectInfoListLiValue]: true,
              [style.projectInfoSelect]: true,
              [style.disable]: true,
            })}
          >
            {zoneIdOptions.map((option) => (
              <option key={option.id} value={option.id}>
                {option.name}
              </option>
            ))}
          </select>
        </div>
        <div className={style.projectInfoListLi}>
          <div className={style.projectInfoListLiLabel}>创建人</div>
          <input
            value={projectInfo.owner}
            disabled
            className={classnames({
              [style.projectInfoListLiValue]: true,
              [style.disable]: true,
            })}
          ></input>
        </div>
        <div className={style.projectInfoListLi}>
          <div className={style.projectInfoListLiLabel}>扣费账号</div>
          <input
            value={projectInfo.tenantUser}
            disabled
            className={classnames({
              [style.projectInfoListLiValue]: true,
              [style.disable]: true,
            })}
          ></input>
        </div>
        <div className={style.projectInfoListLi}>
          <Button
            variant="contained"
            size="large"
            className={style.updateButton}
            onClick={handleClickUpdate}
            style={{ backgroundColor: "#1370ff", color: "#fff" }}
          >
            保存修改
          </Button>
        </div>
        <div className={style.projectInfoListLi}>
          <div className={style.projectInfoListLiLabel}>删除项目</div>
          <div className={style.projectInfoListLiText}>
            删除项目将删除其存储的数据和所有相关资源，并且已删除的项目无法恢复！请谨慎操作！
          </div>
          <Button
            variant="contained"
            size="large"
            className={style.updateButton}
            onClick={handleClickDelete}
            style={{
              backgroundColor: "#fff",
              color: "#FF4E4E",
              border: "1px solid #FF4E4E",
            }}
          >
            删除项目
          </Button>
        </div>
      </div>
    );
  } else {
    return <InformationDisplay infoList={infoList} />;
  }
});

export default memo(BaseInfo);
