/*
 * @Author: 吴永生#A02208 yongsheng.wu@wholion.com
 * @Date: 2022-05-31 10:18:13
 * @LastEditors: 吴永生#A02208 yongsheng.wu@wholion.com
 * @LastEditTime: 2022-06-07 10:47:31
 * @FilePath: /bkunyun/src/views/Project/ProjectSetting/index.tsx
 * @Description: 这是默认设置,请设置`customMade`, 打开koroFileHeader查看配置 进行设置: https://github.com/OBKoro1/koro1FileHeader/wiki/%E9%85%8D%E7%BD%AE
 */
import { toJS } from "mobx";
import { observer } from "mobx-react-lite";

import SelectComponent from "@/components/Material.Ui/Select";
import Table from "@/components/Material.Ui/Table";
import Dialog from "@/components/mui/Dialog";
import { memo, useEffect, useMemo, useState } from "react";
import { Box } from "@mui/material";
import SearchIcon from "@mui/icons-material/Search";
import Input from "@/components/Material.Ui/Input";
import { IResponse, useHttp } from "@/api/http";
import { useStores } from "@/store";
import { useMessage } from "@/components/MySnackbar";
// import Select from "@/components/Material.Ui/Select";
interface IProps {
  setAddMemberDialog: (val: boolean) => void;
  addMemberDialog: boolean;
  getTableList: () => void;
}

const AddMember = observer((props: IProps) => {
  const { addMemberDialog, setAddMemberDialog, getTableList } = props;

  const http = useHttp();
  const { currentProjectStore } = useStores();

  const [tableData, setTableData] = useState([]);
  const [projectMember, setProjectMember] = useState("");
  const [filterTableData, setFilterTableData] = useState([]);
  const Message = useMessage();

  const selectOption = useMemo(() => {
    return [
      { key: "DEVELOPER", label: "研发者" },
      { key: "MANAGER", label: "管理者" },
      { key: "VIEWER", label: "查看者" },
    ];
  }, []);

  const columns = [
    { id: "checkbox", width: 50 },
    { id: "username", label: "项目成员", width: 160 },
    {
      id: "projectRole",
      label: "项目权限",
      width: 160,
      render: () => {
        return (
          <SelectComponent
            option={selectOption}
            size={"xsmall"}
            callback={(value: any) => console.log(value)}
            rootStyle={{
              paddingRight: "0",
              width: "180px",
              border: "1px solid #136EFA",
            }}
            textStyle={{ fontSize: "13px" }}
            sz={"sm"}
            customSvg={{
              width: "32px",
              height: "32px",
              backgroundColor: "rgba(19, 110, 250, 0.1)",
              borderRadius: "4px",
              display: "flex",
              alignItems: "center",
              justifyContent: "center",
            }}
          />
        );
      },
    },
  ];

  useEffect(() => {
    if (!!projectMember) {
      const newVal =
        tableData.filter((item: any) => {
          return item?.username?.includes(projectMember);
        }) || [];
      setFilterTableData(newVal || []);
    } else {
      console.log(2222);
      setFilterTableData(tableData);
    }
  }, [projectMember, tableData]);

  useEffect(() => {
    if (!addMemberDialog) return;
    const projectInfo = toJS(currentProjectStore?.currentProjectInfo);
    http
      .get<IResponse<any>>("/cpp/project/listusers", {
        params: { id: projectInfo?.id || "" },
      })
      .then((res) => {
        if (res.data.length) {
          setTableData(res?.data);
        }
      });
  }, [currentProjectStore?.currentProjectInfo, http, addMemberDialog]);

  const onClose = () => {
    setAddMemberDialog(false);
  };

  const onConfirm = () => {
    const projectInfo = toJS(currentProjectStore?.currentProjectInfo);
    http
      .put<IResponse<any>>("/cpp/project/updatemember", {
        id: projectInfo?.id || "",
      })
      .then((res) => {
        const { errorCode } = res;
        if (errorCode === 0) {
          Message.success("新增成功！");
          getTableList();
          setAddMemberDialog(false);
        }
      });
  };

  return (
    <>
      <Dialog
        open={addMemberDialog}
        onClose={onClose}
        onConfirm={onConfirm}
        title="添加成员"
      >
        <Box>
          <Input
            onChange={(e: any) => {
              setProjectMember(e.target.value);
              console.log(e);
            }}
            fullWidth={true}
            size="xsmall"
            placeholder="搜索项目成员"
            endAdornment={<SearchIcon style={{ color: "#8A9099" }} />}
          />
        </Box>
        <Table
          rowHover={true}
          stickyheader={true}
          rows={filterTableData}
          rowsPerPage="99"
          headCells={columns}
          footer={false}
          tableStyle={{ minWidth: "auto" }}
          borderBottom="none"
        />
      </Dialog>
    </>
  );
});

export default memo(AddMember);
