/*
 * @Author: 吴永生#A02208 yongsheng.wu@wholion.com
 * @Date: 2022-05-31 10:18:13
 * @LastEditors: 吴永生#A02208 yongsheng.wu@wholion.com
 * @LastEditTime: 2022-06-07 11:13:26
 * @FilePath: /bkunyun/src/views/Project/ProjectSetting/index.tsx
 * @Description: 这是默认设置,请设置`customMade`, 打开koroFileHeader查看配置 进行设置: https://github.com/OBKoro1/koro1FileHeader/wiki/%E9%85%8D%E7%BD%AE
 */
import { memo, useCallback, useEffect, useState } from "react";
import _ from "lodash";
import { Box } from "@mui/material";
import Button from "@mui/material/Button";
import SearchIcon from "@mui/icons-material/Search";
import Add from "@mui/icons-material/Add";
import Table from "@/components/Material.Ui/Table";
import { IResponse, useHttp } from "@/api/http";
import Input from "@/components/Material.Ui/Input";
import RemoveItem from "./components/RemoveItem";
import ChangePermission from "./components/ChangePermission";
import AddMember from "./components/AddMember";

import styles from "./index.module.css";
import { IDialogInfo } from "./interface";
import { toJS } from "mobx";
import { useStores } from "@/store";

const ProjectMembers = () => {
  const http = useHttp();

  const { currentProjectStore } = useStores();

  const columns = [
    { id: "username", label: "成员名称" },
    { id: "projectRoleDesc", label: "项目权限" },
    { id: "phone", label: "联系方式" },
    {
      id: "operation",
      label: "操作",
      width: 160,
      render: (item: any) => {
        return (
          <>
            <span
              style={{ color: "#1370FF", cursor: "pointer" }}
              onClick={() => {
                onPermissionBtn(item.username);
              }}
            >
              更改权限
            </span>
            <span
              className={styles.removeItemBox}
              onClick={() => {
                onRemoveItemBtn(item.username);
              }}
            >
              移出项目
            </span>
          </>
        );
      },
    },
  ];

  /** 删除成员 */
  const [removeDialog, setRemoveDialog] = useState<IDialogInfo>({
    isShow: false,
    username: "",
  });
  /** 更改权限 */
  const [permissionDialog, setPermissionDialog] = useState<IDialogInfo>({
    isShow: false,
    username: "",
  });
  /** 添加成员 */
  const [addMemberDialog, setAddMemberDialog] = useState<boolean>(false);

  const [tableData, setTableData] = useState([]);
  const [projectName, setProjectMember] = useState("");
  const [filterTableData, setFilterTableData] = useState([]);

  /** 获取表格数据 */
  const getTableList = useCallback(() => {
    const projectInfo = toJS(currentProjectStore?.currentProjectInfo);
    if (!projectInfo?.id) return;
    http
      .get<IResponse<any>>("/cpp/project/get", {
        params: { id: projectInfo?.id || "" },
      })
      .then((res) => {
        setTableData(res?.data?.members || []);
      });
  }, [currentProjectStore?.currentProjectInfo, http]);

  useEffect(() => {
    getTableList();
  }, [getTableList]);

  useEffect(() => {
    if (!!projectName) {
      const newVal =
        tableData.filter((item: any) => {
          return item?.username?.includes(projectName);
        }) || [];
      setFilterTableData(newVal || []);
    } else {
      console.log(2222);
      setFilterTableData(tableData);
    }
  }, [projectName, tableData]);

  /** 点击添加成员 */
  const onAddMember = () => {
    setAddMemberDialog(true);
  };

  /** 点击删除成员 */
  const onRemoveItemBtn = (userName: string) => {
    setRemoveDialog({ isShow: true, username: userName });
  };

  /** 点击更改权限 */
  const onPermissionBtn = (userName: string) => {
    setPermissionDialog({ isShow: true, username: userName });
  };

  return (
    <>
      <Box className={styles.headerBox}>
        <Input
          onChange={(e: any) => {
            _.debounce(() => {
              setProjectMember(e.target.value);
            }, 200)();
          }}
          placeholder="搜索项目成员"
          size="xsmall"
          endAdornment={<SearchIcon style={{ color: "#8A9099" }} />}
        />
        <Button
          style={{ backgroundColor: "#1370FF " }}
          variant="contained"
          onClick={onAddMember}
          startIcon={<Add />}
          size="small"
        >
          添加成员
        </Button>
      </Box>
      <Table
        rowHover={true}
        stickyheader={true}
        rows={filterTableData}
        rowsPerPage={"99"}
        headCells={columns}
        nopadding={true}
        footer={false}
        tableStyle={{ minWidth: "auto" }}
        borderBottom={"none"}
      />
      <RemoveItem
        removeDialog={removeDialog}
        setRemoveDialog={setRemoveDialog}
        getTableList={getTableList}
      />
      <ChangePermission
        permissionDialog={permissionDialog}
        getTableList={getTableList}
        setPermissionDialog={setPermissionDialog}
      />
      <AddMember
        addMemberDialog={addMemberDialog}
        setAddMemberDialog={setAddMemberDialog}
        getTableList={getTableList}
      />
    </>
  );
};

export default memo(ProjectMembers);
